/*
 * src/sysarg.c
 *
 * Copyright (C) 1998-2002 BigOrno (bigorno@bigorno.net). All rights reserved.
 *
 * The use and distribution terms for this software are contained in the file
 * named README, which can be found in the root of this distribution. By
 * using this software in any fashion, you are agreeing to be bound by the
 * terms of this license.
 *
 * You must not remove this notice, or any other, from this software.
 */

/*
 * 20021010 added test to prevent buffer overrun in -keys parsing.
 */

#include <stdlib.h> // atoi
#include <string.h> // strcmp

#include <SDL.h>

#include "system.h"
#include "game.h"

#include "maps.h"
#include "syssnd.h"

int sysarg_args_period = 0;
int sysarg_args_map = 0;
int sysarg_args_submap = 0;
int sysarg_args_nosound = 0;
int sysarg_args_vol = 0;


/*
 * Fail
 */
void sysarg_fail (char *msg)
{
   sys_printf ("xrick [version #042510]: %s\n"
               "usage: xrick [<options>]\n"
               "options:\n"
               " -h, -help : Display this information.\n"
               " -speed <speed> : Run at speed <speed>. Speed must be an integer between 1 (fast) and 100 (slow). The default is %d\n"
               " -map <map> : Start at map number <map>. <map> must be an integer between 1 and %d. The default is to start at map number 1\n"
               " -submap <submap> : Start at submap <submap>. <submap> must be an integer between 1 and %d. The default is to start at submap number 1 or, if a map was specified, at the first submap of that map.\n"
               " -nosound : Disable sounds. The default is to play with sounds enabled.\n"
               " -vol <vol> : Play sounds at volume <vol>. <vol> must be an integer between 0 (silence) and %d (max). The default is to play sounds at maximal volume (%d).\n",
               msg,
               GAME_PERIOD,
               MAP_NBR_MAPS-1, MAP_NBR_SUBMAPS,
               SYSSND_MAXVOL, SYSSND_MAXVOL);
   exit (1);
}


/*
 * Read and process arguments
 */
void sysarg_init (int argc, char **argv)
{
   int i;

   for (i = 1; i < argc; i++)
   {
      if (!strcmp (argv[i], "-h") || !strcmp (argv[i], "--help"))
         sysarg_fail ("help");

      else if (!strcmp(argv[i], "-s") || !strcmp(argv[i], "--speed"))
      {
         if (++i == argc)
            sysarg_fail ("missing speed value");
         sysarg_args_period = atoi(argv[i]) - 1;
         if (sysarg_args_period < 0 || sysarg_args_period > 99)
            sysarg_fail ("invalid speed value");
      }

      else if (!strcmp(argv[i], "-map"))
      {
         if (++i == argc)
            sysarg_fail ("missing map number");
         sysarg_args_map = atoi(argv[i]) - 1;
         if (sysarg_args_map < 0 || sysarg_args_map >= MAP_NBR_MAPS-1)
            sysarg_fail ("invalid map number");
      }

      else if (!strcmp(argv[i], "-submap"))
      {
         if (++i == argc)
            sysarg_fail ("missing submap number");
         sysarg_args_submap = atoi(argv[i]) - 1;
         if (sysarg_args_submap < 0 || sysarg_args_submap >= MAP_NBR_SUBMAPS)
            sysarg_fail ("invalid submap number");
      }

      else if (!strcmp(argv[i], "-vol"))
      {
         if (++i == argc)
            sysarg_fail ("missing volume");
         sysarg_args_vol = atoi(argv[i]) - 1;
         if (sysarg_args_submap < 0 || sysarg_args_submap >= SYSSND_MAXVOL)
            sysarg_fail ("invalid volume");
      }

      else if (!strcmp(argv[i], "-n") || !strcmp(argv[i], "--nosound"))
         sysarg_args_nosound = 1;

      else
         sysarg_fail ("invalid argument(s)");
   }

   // this is dirty (sort of)
   if (sysarg_args_submap >= 0 && sysarg_args_submap < 9)
      sysarg_args_map = 0;
   if (sysarg_args_submap >= 9 && sysarg_args_submap < 20)
      sysarg_args_map = 1;
   if (sysarg_args_submap >= 20 && sysarg_args_submap < 38)
      sysarg_args_map = 2;
   if (sysarg_args_submap >= 38)
      sysarg_args_map = 3;

   if (sysarg_args_submap == 9 || sysarg_args_submap == 20 || sysarg_args_submap == 38)
      sysarg_args_submap = 0;
   if (sysarg_args_submap == 18)
      sysarg_args_submap = 19;
}
